==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/history/translations/history_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Kies een datum</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="59"/>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Luistergeschiedenis-plug-in</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Over de Luistergeschiedenis-plug-in</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Luistergeschiedenis-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Deze plug-in verzamelt informatie over beluisterde nummers</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Titel formaat:</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Tijdspanne</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>Van:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Tot:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Vorige week</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Vorige maand</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Uitvoeren</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Aangeleverd door</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Aantal keer afgespeeld</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Topnummers</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Topartiesten</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Topgenres</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="124"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="125"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="200"/>
        <source>MM-yyyy</source>
        <translation>MM-yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="201"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/history/translations/history_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Kies een datum</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="57"/>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="58"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Afspeelgeschiedenis-plug-in</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Over de Afspeelgeschiedenis-plug-in</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Afspeelgeschiedenis-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Deze plug-in verzamelt informatie over afgespeelde nummers</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Titelopmaak:</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Tijdspanne</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>Van:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Tot:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Vorige week</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Vorige maand</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Uitvoeren</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Aangeleverd door</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Aantal keer afgespeeld</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Topnummers</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Topartiesten</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Topgenres</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="130"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="131"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="198"/>
        <source>MM-yyyy</source>
        <translation>MM-yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="199"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="499"/>
        <source>Add to Playlist</source>
        <translation>Toevoegen aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="500"/>
        <source>&amp;View Track Details</source>
        <translation>Nummerin&amp;formatie bekijken</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="502"/>
        <source>Remove from History</source>
        <translation>Verwijderen uit geschiedenis</translation>
    </message>
</context>
</TS>
